if ShowMyChat == nil then ShowMyChat = {} end

ShowMyChat.panel_addon = {
    type = "panel",
    name = "Show My Chat",
    displayName = "Show My Chat",
    author = "|c880000@|r|cf44444Lexynide|r",
    version = string.format("%.2f", ShowMyChat.addonVersion / 100.0),
    registerForRefresh = true,
    registerForDefaults = true,
    keywords = "ShowMyChat, show, chat, keep, toggle, vendor"
}

ShowMyChat.panel_options = {
    {
        type = "slider",
        name = "Delay (ms)",
        getFunc = function() return ShowMyChat.config.delay end,
        setFunc = function(v) ShowMyChat.config.delay = v end,
        min = 0,
        max = 1000,
        default = ShowMyChat.defaults.delay,
        tooltip = "This is the response delay when the state of chat changes due to activating a certain scene (vendor, crafting, etc). Lower the value for faster response, raise it if you notice instability.",
    },
    {
        type = "description",
        title = "Behavior modes",
        text = "Each option below comes with one of three modes: \n|cFFFF00Keep the chat|r - will preserve previous state of the chat prior to state change caused by an event (such as interacting with a crafting station or bank)\n|cFFFF00Hide the chat|r - will hide the chat while interacting and then will bring it back up if it wasn't hidden\n|cFFFF00Show the chat|r - will show the chat while interacting and then will hide it afterwards if it wasn't visible before."
    },
    --- Vendors
    {
        type = "checkbox",
        name = "Handle Vendors",
        getFunc = function() return ShowMyChat.config.enable_store end,
        setFunc = function(v) ShowMyChat.config.enable_store = v end,
        default = ShowMyChat.defaults.enable_store,
        tooltip = "Enable or disable vendor event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Vendor behavior",
        tooltip = "Vendor scene (Assistant Merchants, World NPCs)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_store end,
        setFunc = function(v) ShowMyChat.config.mode_store = v end,
        disabled = function() return not ShowMyChat.config.enable_store end,
        width = "half",
    },
    --- Banks
    {
        type = "checkbox",
        name = "Handle Banks",
        getFunc = function() return ShowMyChat.config.enable_bank end,
        setFunc = function(v) ShowMyChat.config.enable_bank = v end,
        default = ShowMyChat.defaults.enable_bank,
        tooltip = "Enable or disable bank event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Bank behavior",
        tooltip = "Bank scene (Assistant Bank, World NPCs)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_bank end,
        setFunc = function(v) ShowMyChat.config.mode_bank = v end,
        disabled = function() return not ShowMyChat.config.enable_bank end,
        width = "half",
    },
    --- Guild Banks
    {
        type = "checkbox",
        name = "Handle Guild Banks",
        getFunc = function() return ShowMyChat.config.enable_gbank end,
        setFunc = function(v) ShowMyChat.config.enable_gbank = v end,
        default = ShowMyChat.defaults.enable_gbank,
        tooltip = "Enable or disable guild bank event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Guild bank behavior",
        tooltip = "Guild bank scene",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_gbank end,
        setFunc = function(v) ShowMyChat.config.mode_gbank = v end,
        disabled = function() return not ShowMyChat.config.enable_gbank end,
        width = "half",
    },
    --- Guild Store
    {
        type = "checkbox",
        name = "Handle Guild Store",
        getFunc = function() return ShowMyChat.config.enable_gstore end,
        setFunc = function(v) ShowMyChat.config.enable_gstore = v end,
        default = ShowMyChat.defaults.enable_gstore,
        tooltip = "Enable or disable guild bank event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Guild store behavior",
        tooltip = "Guild store scene",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_gstore end,
        setFunc = function(v) ShowMyChat.config.mode_gstore = v end,
        disabled = function() return not ShowMyChat.config.enable_gstore end,
        width = "half",
    },
    --- Crafting Stations
    {
        type = "checkbox",
        name = "Handle Crafting Stations",
        getFunc = function() return ShowMyChat.config.enable_crafting end,
        setFunc = function(v) ShowMyChat.config.enable_crafting = v end,
        default = ShowMyChat.defaults.enable_crafting,
        tooltip = "Enable or disable crafting station event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Crafting behavior",
        tooltip = "Crafting scene (crafting stations like Blacksmithing, Alchemy, Cooking)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_crafting end,
        setFunc = function(v) ShowMyChat.config.mode_crafting = v end,
        disabled = function() return not ShowMyChat.config.enable_crafting end,
        width = "half",
    },
    --- Outfit Stations
    {
        type = "checkbox",
        name = "Handle Outfit Stations",
        getFunc = function() return ShowMyChat.config.enable_outfitting end,
        setFunc = function(v) ShowMyChat.config.enable_outfitting = v end,
        default = ShowMyChat.defaults.enable_outfitting,
        tooltip = "Enable or disable outfit station event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Outfit Station behavior",
        tooltip = "Outfit scene (outfit stations)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_outfitting end,
        setFunc = function(v) ShowMyChat.config.mode_outfitting = v end,
        disabled = function() return not ShowMyChat.config.enable_outfitting end,
        width = "half",
    },
    --- Stables
    {
        type = "checkbox",
        name = "Handle Stables",
        getFunc = function() return ShowMyChat.config.enable_stables end,
        setFunc = function(v) ShowMyChat.config.enable_stables = v end,
        default = ShowMyChat.defaults.enable_stables,
        tooltip = "Enable or disable stables event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Stables behavior",
        tooltip = "Stables scene (Stablemaster NPCs)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_stables end,
        setFunc = function(v) ShowMyChat.config.mode_stables = v end,
        disabled = function() return not ShowMyChat.config.enable_stables end,
        width = "half",
    },
    -- Preview
    {
        type = "checkbox",
        name = "Handle Previews",
        getFunc = function() return ShowMyChat.config.enable_preview end,
        setFunc = function(v) ShowMyChat.config.enable_preview = v end,
        default = ShowMyChat.defaults.enable_preview,
        tooltip = "Enable or disable preview event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Preview scene behavior",
        tooltip = "Preview scene (Crown Store, Outfit Styles menu, Guild Store item previews, Furniture previews)",
        choices = {"show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_preview end,
        setFunc = function(v) ShowMyChat.config.mode_preview = v end,
        disabled = function() return not ShowMyChat.config.enable_preview end,
        width = "half",
    },
    -- Armory
    {
        type = "checkbox",
        name = "Handle Armory",
        getFunc = function() return ShowMyChat.config.enable_armory end,
        setFunc = function(v) ShowMyChat.config.enable_armory = v end,
        default = ShowMyChat.defaults.enable_armory,
        tooltip = "Enable or disable armory event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Armory behavior",
        tooltip = "Armory scene (Armory Station and Armory NPCs)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_armory end,
        setFunc = function(v) ShowMyChat.config.mode_armory = v end,
        disabled = function() return not ShowMyChat.config.enable_armory end,
        width = "half",
    },
    -- Scrying
    {
        type = "checkbox",
        name = "Handle Scrying",
        getFunc = function() return ShowMyChat.config.enable_scrying end,
        setFunc = function(v) ShowMyChat.config.enable_scrying = v end,
        default = ShowMyChat.defaults.enable_scrying,
        tooltip = "Enable or disable scrying event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Scrying behavior",
        tooltip = "Scrying scene (Antiquarian skill)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_scrying end,
        setFunc = function(v) ShowMyChat.config.mode_scrying = v end,
        disabled = function() return not ShowMyChat.config.enable_scrying end,
        width = "half",
    },
    -- Excavating
    {
        type = "checkbox",
        name = "Handle Excavating",
        getFunc = function() return ShowMyChat.config.enable_excavating end,
        setFunc = function(v) ShowMyChat.config.enable_excavating = v end,
        default = ShowMyChat.defaults.enable_excavating,
        tooltip = "Enable or disable excavating event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Excavating behavior",
        tooltip = "Excavating scene (Antiquarian skill)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_excavating end,
        setFunc = function(v) ShowMyChat.config.mode_excavating = v end,
        disabled = function() return not ShowMyChat.config.enable_excavating end,
        width = "half",
    },
    -- Tales of Tribute
    {
        type = "checkbox",
        name = "Handle Tales of Tribute",
        getFunc = function() return ShowMyChat.config.enable_tot end,
        setFunc = function(v) ShowMyChat.config.enable_tot = v end,
        default = ShowMyChat.defaults.enable_tot,
        tooltip = "Enable or disable ToT card game event handling.",
        width = "half",
        requiresReload = true,
    },
    {
        type = "dropdown",
        name = "Tales of Tribute behavior",
        tooltip = "Tales of Tribute scene (card game match)",
        choices = {"keep", "show", "hide"},
        getFunc = function() return ShowMyChat.config.mode_tot end,
        setFunc = function(v) ShowMyChat.config.mode_tot = v end,
        disabled = function() return not ShowMyChat.config.enable_tot end,
        width = "half",
    },
} 
